@@ -22,12 +22,13 @@
 #include "php_phongo.h"
 #include "phongo_error.h"
 #include "phongo_util.h"
+#include "CursorId_arginfo.h"
 
 zend_class_entry* php_phongo_cursorid_ce;
 
 /* Initialize the object from a numeric string and return whether it was
  * successful. An exception will be thrown on error. */
-static bool php_phongo_cursorid_init_from_string(php_phongo_cursorid_t* intern, const char* s_id, size_t s_id_len) /* {{{ */
+static bool php_phongo_cursorid_init_from_string(php_phongo_cursorid_t* intern, const char* s_id, size_t s_id_len)
 {
 	int64_t id;
 
@@ -39,11 +40,11 @@ static bool php_phongo_cursorid_init_from_string(php_phongo_cursorid_t* intern,
 	intern->id          = id;
 	intern->initialized = true;
 	return true;
-} /* }}} */
+}
 
 /* Initialize the object from a HashTable and return whether it was successful.
  * An exception will be thrown on error. */
-static bool php_phongo_cursorid_init_from_hash(php_phongo_cursorid_t* intern, HashTable* props) /* {{{ */
+static bool php_phongo_cursorid_init_from_hash(php_phongo_cursorid_t* intern, HashTable* props)
 {
 	zval* value;
 
@@ -53,9 +54,9 @@ static bool php_phongo_cursorid_init_from_hash(php_phongo_cursorid_t* intern, Ha
 
 	phongo_throw_exception(PHONGO_ERROR_INVALID_ARGUMENT, "%s initialization requires \"id\" string field", ZSTR_VAL(php_phongo_cursorid_ce->name));
 	return false;
-} /* }}} */
+}
 
-static HashTable* php_phongo_cursorid_get_properties_hash(phongo_compat_object_handler_type* object, bool is_temp, bool is_serialize) /* {{{ */
+static HashTable* php_phongo_cursorid_get_properties_hash(phongo_compat_object_handler_type* object, bool is_temp, bool is_serialize)
 {
 	php_phongo_cursorid_t* intern;
 	HashTable*             props;
@@ -88,23 +89,17 @@ static HashTable* php_phongo_cursorid_get_properties_hash(phongo_compat_object_h
 	}
 
 	return props;
-} /* }}} */
+}
 
-/* {{{ proto MongoDB\Driver\CursorId MongoDB\Driver\CursorId::__set_state(array $properties)
-*/
-static PHP_METHOD(CursorId, __set_state)
+PHP_METHOD(MongoDB_Driver_CursorId, __set_state)
 {
-	zend_error_handling    error_handling;
 	php_phongo_cursorid_t* intern;
 	HashTable*             props;
 	zval*                  array;
 
-	zend_replace_error_handling(EH_THROW, phongo_exception_from_phongo_domain(PHONGO_ERROR_INVALID_ARGUMENT), &error_handling);
-	if (zend_parse_parameters(ZEND_NUM_ARGS(), "a", &array) == FAILURE) {
-		zend_restore_error_handling(&error_handling);
-		return;
-	}
-	zend_restore_error_handling(&error_handling);
+	PHONGO_PARSE_PARAMETERS_START(1, 1)
+	Z_PARAM_ARRAY(array)
+	PHONGO_PARSE_PARAMETERS_END();
 
 	object_init_ex(return_value, php_phongo_cursorid_ce);
 
@@ -112,47 +107,32 @@ static PHP_METHOD(CursorId, __set_state)
 	props  = Z_ARRVAL_P(array);
 
 	php_phongo_cursorid_init_from_hash(intern, props);
-} /* }}} */
+}
 
-/* {{{ proto string MongoDB\Driver\CursorId::__toString()
-   Returns the string representation of the CursorId */
-static PHP_METHOD(CursorId, __toString)
+/* Returns the string representation of the CursorId */
+PHP_METHOD(MongoDB_Driver_CursorId, __toString)
 {
-	zend_error_handling    error_handling;
 	php_phongo_cursorid_t* intern;
 	char*                  tmp;
 	int                    tmp_len;
 
 	intern = Z_CURSORID_OBJ_P(getThis());
 
-	zend_replace_error_handling(EH_THROW, phongo_exception_from_phongo_domain(PHONGO_ERROR_INVALID_ARGUMENT), &error_handling);
-	if (zend_parse_parameters_none() == FAILURE) {
-		zend_restore_error_handling(&error_handling);
-		return;
-	}
-	zend_restore_error_handling(&error_handling);
+	PHONGO_PARSE_PARAMETERS_NONE();
 
 	tmp_len = spprintf(&tmp, 0, "%" PRId64, intern->id);
 	RETVAL_STRINGL(tmp, tmp_len);
 	efree(tmp);
-} /* }}} */
+}
 
-/* {{{ proto string MongoDB\Driver\CursorId::serialize()
-*/
-static PHP_METHOD(CursorId, serialize)
+PHP_METHOD(MongoDB_Driver_CursorId, serialize)
 {
-	zend_error_handling    error_handling;
 	php_phongo_cursorid_t* intern;
 	zval                   retval;
 	php_serialize_data_t   var_hash;
 	smart_str              buf = { 0 };
 
-	zend_replace_error_handling(EH_THROW, phongo_exception_from_phongo_domain(PHONGO_ERROR_INVALID_ARGUMENT), &error_handling);
-	if (zend_parse_parameters_none() == FAILURE) {
-		zend_restore_error_handling(&error_handling);
-		return;
-	}
-	zend_restore_error_handling(&error_handling);
+	PHONGO_PARSE_PARAMETERS_NONE();
 
 	intern = Z_CURSORID_OBJ_P(getThis());
 
@@ -168,13 +148,10 @@ static PHP_METHOD(CursorId, serialize)
 
 	smart_str_free(&buf);
 	zval_ptr_dtor(&retval);
-} /* }}} */
+}
 
-/* {{{ proto void MongoDB\Driver\CursorId::unserialize(string $serialized)
-*/
-static PHP_METHOD(CursorId, unserialize)
+PHP_METHOD(MongoDB_Driver_CursorId, unserialize)
 {
-	zend_error_handling    error_handling;
 	php_phongo_cursorid_t* intern;
 	char*                  serialized;
 	size_t                 serialized_len;
@@ -183,12 +160,9 @@ static PHP_METHOD(CursorId, unserialize)
 
 	intern = Z_CURSORID_OBJ_P(getThis());
 
-	zend_replace_error_handling(EH_THROW, phongo_exception_from_phongo_domain(PHONGO_ERROR_INVALID_ARGUMENT), &error_handling);
-	if (zend_parse_parameters(ZEND_NUM_ARGS(), "s", &serialized, &serialized_len) == FAILURE) {
-		zend_restore_error_handling(&error_handling);
-		return;
-	}
-	zend_restore_error_handling(&error_handling);
+	PHONGO_PARSE_PARAMETERS_START(1, 1)
+	Z_PARAM_STRING(serialized, serialized_len)
+	PHONGO_PARSE_PARAMETERS_END();
 
 	PHP_VAR_UNSERIALIZE_INIT(var_hash);
 	if (!php_var_unserialize(&props, (const unsigned char**) &serialized, (unsigned char*) serialized + serialized_len, &var_hash)) {
@@ -202,20 +176,16 @@ static PHP_METHOD(CursorId, unserialize)
 
 	php_phongo_cursorid_init_from_hash(intern, HASH_OF(&props));
 	zval_ptr_dtor(&props);
-} /* }}} */
+}
 
-/* {{{ proto array MongoDB\Driver\CursorId::__serialize()
-*/
-static PHP_METHOD(CursorId, __serialize)
+PHP_METHOD(MongoDB_Driver_CursorId, __serialize)
 {
 	PHONGO_PARSE_PARAMETERS_NONE();
 
 	RETURN_ARR(php_phongo_cursorid_get_properties_hash(PHONGO_COMPAT_OBJ_P(getThis()), true, true));
-} /* }}} */
+}
 
-/* {{{ proto void MongoDB\Driver\CursorId::__unserialize(array $data)
-*/
-static PHP_METHOD(CursorId, __unserialize)
+PHP_METHOD(MongoDB_Driver_CursorId, __unserialize)
 {
 	zval* data;
 
@@ -224,45 +194,14 @@ static PHP_METHOD(CursorId, __unserialize)
 	PHONGO_PARSE_PARAMETERS_END();
 
 	php_phongo_cursorid_init_from_hash(Z_CURSORID_OBJ_P(getThis()), Z_ARRVAL_P(data));
-} /* }}} */
+}
 
-/* {{{ MongoDB\Driver\CursorId function entries */
-/* clang-format off */
-ZEND_BEGIN_ARG_INFO_EX(ai_CursorId___set_state, 0, 0, 1)
-	ZEND_ARG_ARRAY_INFO(0, properties, 0)
-ZEND_END_ARG_INFO()
+PHONGO_DISABLED_CONSTRUCTOR(MongoDB_Driver_CursorId)
 
-ZEND_BEGIN_ARG_WITH_RETURN_TYPE_INFO_EX(ai_CursorId___toString, 0, 0, IS_STRING, 0)
-ZEND_END_ARG_INFO()
-
-ZEND_BEGIN_ARG_INFO_EX(ai_CursorId___unserialize, 0, 0, 1)
-	ZEND_ARG_ARRAY_INFO(0, data, 0)
-ZEND_END_ARG_INFO()
-
-ZEND_BEGIN_ARG_INFO_EX(ai_CursorId_unserialize, 0, 0, 1)
-	ZEND_ARG_INFO(0, serialized)
-ZEND_END_ARG_INFO()
-
-ZEND_BEGIN_ARG_INFO_EX(ai_CursorId_void, 0, 0, 0)
-ZEND_END_ARG_INFO()
-
-static zend_function_entry php_phongo_cursorid_me[] = {
-	PHP_ME(CursorId, __serialize, ai_CursorId_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
-	PHP_ME(CursorId, __set_state, ai_CursorId___set_state, ZEND_ACC_PUBLIC | ZEND_ACC_STATIC)
-	PHP_ME(CursorId, __toString, ai_CursorId___toString, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
-	PHP_ME(CursorId, __unserialize, ai_CursorId___unserialize, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
-	PHP_ME(CursorId, serialize, ai_CursorId_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
-	PHP_ME(CursorId, unserialize, ai_CursorId_unserialize, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
-	ZEND_NAMED_ME(__construct, PHP_FN(MongoDB_disabled___construct), ai_CursorId_void, ZEND_ACC_PRIVATE | ZEND_ACC_FINAL)
-	PHP_FE_END
-};
-/* clang-format on */
-/* }}} */
-
-/* {{{ MongoDB\Driver\CursorId object handlers */
+/* MongoDB\Driver\CursorId object handlers */
 static zend_object_handlers php_phongo_handler_cursorid;
 
-static void php_phongo_cursorid_free_object(zend_object* object) /* {{{ */
+static void php_phongo_cursorid_free_object(zend_object* object)
 {
 	php_phongo_cursorid_t* intern = Z_OBJ_CURSORID(object);
 
@@ -272,9 +211,9 @@ static void php_phongo_cursorid_free_object(zend_object* object) /* {{{ */
 		zend_hash_destroy(intern->properties);
 		FREE_HASHTABLE(intern->properties);
 	}
-} /* }}} */
+}
 
-static zend_object* php_phongo_cursorid_create_object(zend_class_entry* class_type) /* {{{ */
+static zend_object* php_phongo_cursorid_create_object(zend_class_entry* class_type)
 {
 	php_phongo_cursorid_t* intern = zend_object_alloc(sizeof(php_phongo_cursorid_t), class_type);
 
@@ -284,30 +223,23 @@ static zend_object* php_phongo_cursorid_create_object(zend_class_entry* class_ty
 	intern->std.handlers = &php_phongo_handler_cursorid;
 
 	return &intern->std;
-} /* }}} */
+}
 
-static HashTable* php_phongo_cursorid_get_debug_info(phongo_compat_object_handler_type* object, int* is_temp) /* {{{ */
+static HashTable* php_phongo_cursorid_get_debug_info(phongo_compat_object_handler_type* object, int* is_temp)
 {
 	*is_temp = 1;
 	return php_phongo_cursorid_get_properties_hash(object, true, false);
-} /* }}} */
-/* }}} */
+}
 
-static HashTable* php_phongo_cursorid_get_properties(phongo_compat_object_handler_type* object) /* {{{ */
+static HashTable* php_phongo_cursorid_get_properties(phongo_compat_object_handler_type* object)
 {
 	return php_phongo_cursorid_get_properties_hash(object, false, false);
-} /* }}} */
+}
 
-void php_phongo_cursorid_init_ce(INIT_FUNC_ARGS) /* {{{ */
+void php_phongo_cursorid_init_ce(INIT_FUNC_ARGS)
 {
-	zend_class_entry ce;
-
-	INIT_NS_CLASS_ENTRY(ce, "MongoDB\\Driver", "CursorId", php_phongo_cursorid_me);
-	php_phongo_cursorid_ce                = zend_register_internal_class(&ce);
+	php_phongo_cursorid_ce                = register_class_MongoDB_Driver_CursorId(zend_ce_serializable);
 	php_phongo_cursorid_ce->create_object = php_phongo_cursorid_create_object;
-	PHONGO_CE_FINAL(php_phongo_cursorid_ce);
-
-	zend_class_implements(php_phongo_cursorid_ce, 1, zend_ce_serializable);
 
 #if PHP_VERSION_ID >= 80000
 	zend_class_implements(php_phongo_cursorid_ce, 1, zend_ce_stringable);
@@ -318,4 +250,4 @@ void php_phongo_cursorid_init_ce(INIT_FUNC_ARGS) /* {{{ */
 	php_phongo_handler_cursorid.get_properties = php_phongo_cursorid_get_properties;
 	php_phongo_handler_cursorid.free_obj       = php_phongo_cursorid_free_object;
 	php_phongo_handler_cursorid.offset         = XtOffsetOf(php_phongo_cursorid_t, std);
-} /* }}} */
+}
