@@ -26,22 +26,10 @@
 #include "phongo_error.h"
 
 #include "MongoDB/ServerDescription.h"
+#include "ServerDescription_arginfo.h"
 
 zend_class_entry* php_phongo_serverdescription_ce;
 
-/* Note: these constants are derived from mongoc_server_description_type, since
- * since mongoc_server_description_type_t is private. */
-#define PHONGO_SERVER_TYPE_UNKNOWN "Unknown"
-#define PHONGO_SERVER_TYPE_STANDALONE "Standalone"
-#define PHONGO_SERVER_TYPE_MONGOS "Mongos"
-#define PHONGO_SERVER_TYPE_POSSIBLE_PRIMARY "PossiblePrimary"
-#define PHONGO_SERVER_TYPE_RS_PRIMARY "RSPrimary"
-#define PHONGO_SERVER_TYPE_RS_SECONDARY "RSSecondary"
-#define PHONGO_SERVER_TYPE_RS_ARBITER "RSArbiter"
-#define PHONGO_SERVER_TYPE_RS_OTHER "RSOther"
-#define PHONGO_SERVER_TYPE_RS_GHOST "RSGhost"
-#define PHONGO_SERVER_TYPE_LOAD_BALANCER "LoadBalancer"
-
 php_phongo_server_description_type_map_t
 	php_phongo_server_description_type_map[PHONGO_SERVER_DESCRIPTION_TYPES] = {
 		{ PHONGO_SERVER_UNKNOWN, PHONGO_SERVER_TYPE_UNKNOWN },
@@ -56,9 +44,11 @@ php_phongo_server_description_type_map_t
 		{ PHONGO_SERVER_LOAD_BALANCER, PHONGO_SERVER_TYPE_LOAD_BALANCER },
 	};
 
-/* {{{ proto array MongoDB\Driver\ServerDescription::getHelloResponse()
-   Returns the most recent "hello" response */
-static PHP_METHOD(ServerDescription, getHelloResponse)
+PHONGO_DISABLED_CONSTRUCTOR(MongoDB_Driver_ServerDescription)
+PHONGO_DISABLED_WAKEUP(MongoDB_Driver_ServerDescription)
+
+/* Returns the most recent "hello" response */
+static PHP_METHOD(MongoDB_Driver_ServerDescription, getHelloResponse)
 {
 	php_phongo_serverdescription_t* intern;
 	const bson_t*                   helloResponse;
@@ -77,18 +67,17 @@ static PHP_METHOD(ServerDescription, getHelloResponse)
 
 	PHONGO_BSON_INIT_DEBUG_STATE(state);
 
-	if (!php_phongo_bson_to_zval_ex(bson_get_data(helloResponse), helloResponse->len, &state)) {
+	if (!php_phongo_bson_to_zval_ex(helloResponse, &state)) {
 		/* Exception should already have been thrown */
 		zval_ptr_dtor(&state.zchild);
 		return;
 	}
 
 	RETURN_ZVAL(&state.zchild, 0, 1);
-} /* }}} */
+}
 
-/* {{{ proto string MongoDB\Driver\ServerDescription::getHost()
-   Returns the server's hostname */
-static PHP_METHOD(ServerDescription, getHost)
+/* Returns the server's hostname */
+static PHP_METHOD(MongoDB_Driver_ServerDescription, getHost)
 {
 	php_phongo_serverdescription_t* intern;
 
@@ -97,11 +86,10 @@ static PHP_METHOD(ServerDescription, getHost)
 	PHONGO_PARSE_PARAMETERS_NONE();
 
 	RETVAL_STRING(mongoc_server_description_host(intern->server_description)->host);
-} /* }}} */
+}
 
-/* {{{ proto integer MongoDB\Driver\ServerDescription::getLastUpdateTime()
-   Returns the server's last update time, in microseconds */
-static PHP_METHOD(ServerDescription, getLastUpdateTime)
+/* Returns the server's last update time, in microseconds */
+static PHP_METHOD(MongoDB_Driver_ServerDescription, getLastUpdateTime)
 {
 	php_phongo_serverdescription_t* intern;
 	int64_t                         last_update_time;
@@ -119,11 +107,10 @@ static PHP_METHOD(ServerDescription, getLastUpdateTime)
 #endif
 
 	RETVAL_LONG(last_update_time);
-} /* }}} */
+}
 
-/* {{{ proto integer MongoDB\Driver\ServerDescription::getPort()
-   Returns the server's port */
-static PHP_METHOD(ServerDescription, getPort)
+/* Returns the server's port */
+static PHP_METHOD(MongoDB_Driver_ServerDescription, getPort)
 {
 	php_phongo_serverdescription_t* intern;
 
@@ -132,11 +119,10 @@ static PHP_METHOD(ServerDescription, getPort)
 	PHONGO_PARSE_PARAMETERS_NONE();
 
 	RETVAL_LONG(mongoc_server_description_host(intern->server_description)->port);
-} /* }}} */
+}
 
-/* {{{ proto integer MongoDB\Driver\ServerDescription::getRoundTripTime()
-   Returns the server's round trip time, in milliseconds */
-static PHP_METHOD(ServerDescription, getRoundTripTime)
+/* Returns the server's round trip time, in milliseconds */
+static PHP_METHOD(MongoDB_Driver_ServerDescription, getRoundTripTime)
 {
 	php_phongo_serverdescription_t* intern;
 
@@ -148,13 +134,12 @@ static PHP_METHOD(ServerDescription, getRoundTripTime)
 	if (mongoc_server_description_round_trip_time(intern->server_description) == -1) {
 		RETVAL_NULL();
 	} else {
-		RETVAL_LONG((zend_long) mongoc_server_description_round_trip_time(intern->server_description));
+		RETVAL_LONG(mongoc_server_description_round_trip_time(intern->server_description));
 	}
-} /* }}} */
+}
 
-/* {{{ proto string MongoDB\Driver\ServerDescription::getType()
-   Returns the server's node type */
-static PHP_METHOD(ServerDescription, getType)
+/* Returns the server's node type */
+static PHP_METHOD(MongoDB_Driver_ServerDescription, getType)
 {
 	php_phongo_serverdescription_t* intern;
 
@@ -163,30 +148,12 @@ static PHP_METHOD(ServerDescription, getType)
 	PHONGO_PARSE_PARAMETERS_NONE();
 
 	RETVAL_STRING(mongoc_server_description_type(intern->server_description));
-} /* }}} */
+}
 
-/* {{{ MongoDB\Driver\ServerDescription function entries */
-ZEND_BEGIN_ARG_INFO_EX(ai_ServerDescription_void, 0, 0, 0)
-ZEND_END_ARG_INFO()
-
-static zend_function_entry php_phongo_serverdescription_me[] = {
-	/* clang-format off */
-	PHP_ME(ServerDescription, getHelloResponse, ai_ServerDescription_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
-	PHP_ME(ServerDescription, getHost, ai_ServerDescription_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
-	PHP_ME(ServerDescription, getLastUpdateTime, ai_ServerDescription_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
-	PHP_ME(ServerDescription, getPort, ai_ServerDescription_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
-	PHP_ME(ServerDescription, getRoundTripTime, ai_ServerDescription_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
-	PHP_ME(ServerDescription, getType, ai_ServerDescription_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
-	ZEND_NAMED_ME(__construct, PHP_FN(MongoDB_disabled___construct), ai_ServerDescription_void, ZEND_ACC_PRIVATE | ZEND_ACC_FINAL)
-	PHP_FE_END
-	/* clang-format on */
-};
-/* }}} */
-
-/* {{{ MongoDB\Driver\ServerDescription object handlers */
+/* MongoDB\Driver\ServerDescription object handlers */
 static zend_object_handlers php_phongo_handler_serverdescription;
 
-static void php_phongo_serverdescription_free_object(zend_object* object) /* {{{ */
+static void php_phongo_serverdescription_free_object(zend_object* object)
 {
 	php_phongo_serverdescription_t* intern = Z_OBJ_SERVERDESCRIPTION(object);
 
@@ -202,7 +169,7 @@ static void php_phongo_serverdescription_free_object(zend_object* object) /* {{{
 	}
 }
 
-static zend_object* php_phongo_serverdescription_create_object(zend_class_entry* class_type) /* {{{ */
+static zend_object* php_phongo_serverdescription_create_object(zend_class_entry* class_type)
 {
 	php_phongo_serverdescription_t* intern = zend_object_alloc(sizeof(php_phongo_serverdescription_t), class_type);
 
@@ -212,9 +179,9 @@ static zend_object* php_phongo_serverdescription_create_object(zend_class_entry*
 	intern->std.handlers = &php_phongo_handler_serverdescription;
 
 	return &intern->std;
-} /* }}} */
+}
 
-HashTable* php_phongo_serverdescription_get_properties_hash(phongo_compat_object_handler_type* object, bool is_debug) /* {{{ */
+HashTable* php_phongo_serverdescription_get_properties_hash(phongo_compat_object_handler_type* object, bool is_debug)
 {
 	php_phongo_serverdescription_t* intern = NULL;
 	HashTable*                      props;
@@ -247,7 +214,7 @@ HashTable* php_phongo_serverdescription_get_properties_hash(phongo_compat_object
 
 		PHONGO_BSON_INIT_DEBUG_STATE(state);
 
-		if (!php_phongo_bson_to_zval_ex(bson_get_data(hello_response), hello_response->len, &state)) {
+		if (!php_phongo_bson_to_zval_ex(hello_response, &state)) {
 			zval_ptr_dtor(&state.zchild);
 			goto done;
 		}
@@ -280,7 +247,7 @@ HashTable* php_phongo_serverdescription_get_properties_hash(phongo_compat_object
 		if (mongoc_server_description_round_trip_time(intern->server_description) == -1) {
 			ZVAL_NULL(&round_trip_time);
 		} else {
-			ZVAL_LONG(&round_trip_time, (zend_long) mongoc_server_description_round_trip_time(intern->server_description));
+			ZVAL_LONG(&round_trip_time, mongoc_server_description_round_trip_time(intern->server_description));
 		}
 
 		zend_hash_str_update(props, "round_trip_time", sizeof("round_trip_time") - 1, &round_trip_time);
@@ -288,28 +255,23 @@ HashTable* php_phongo_serverdescription_get_properties_hash(phongo_compat_object
 
 done:
 	return props;
-} /* }}} */
+}
 
-static HashTable* php_phongo_serverdescription_get_debug_info(phongo_compat_object_handler_type* object, int* is_temp) /* {{{ */
+static HashTable* php_phongo_serverdescription_get_debug_info(phongo_compat_object_handler_type* object, int* is_temp)
 {
 	*is_temp = 1;
 	return php_phongo_serverdescription_get_properties_hash(object, true);
-} /* }}} */
+}
 
-static HashTable* php_phongo_serverdescription_get_properties(phongo_compat_object_handler_type* object) /* {{{ */
+static HashTable* php_phongo_serverdescription_get_properties(phongo_compat_object_handler_type* object)
 {
 	return php_phongo_serverdescription_get_properties_hash(object, false);
-} /* }}} */
-/* }}} */
+}
 
-void php_phongo_serverdescription_init_ce(INIT_FUNC_ARGS) /* {{{ */
+void php_phongo_serverdescription_init_ce(INIT_FUNC_ARGS)
 {
-	zend_class_entry ce;
-
-	INIT_NS_CLASS_ENTRY(ce, "MongoDB\\Driver", "ServerDescription", php_phongo_serverdescription_me);
-	php_phongo_serverdescription_ce                = zend_register_internal_class(&ce);
+	php_phongo_serverdescription_ce                = register_class_MongoDB_Driver_ServerDescription();
 	php_phongo_serverdescription_ce->create_object = php_phongo_serverdescription_create_object;
-	PHONGO_CE_FINAL(php_phongo_serverdescription_ce);
 	PHONGO_CE_DISABLE_SERIALIZATION(php_phongo_serverdescription_ce);
 
 	memcpy(&php_phongo_handler_serverdescription, phongo_get_std_object_handlers(), sizeof(zend_object_handlers));
@@ -317,20 +279,9 @@ void php_phongo_serverdescription_init_ce(INIT_FUNC_ARGS) /* {{{ */
 	php_phongo_handler_serverdescription.get_properties = php_phongo_serverdescription_get_properties;
 	php_phongo_handler_serverdescription.free_obj       = php_phongo_serverdescription_free_object;
 	php_phongo_handler_serverdescription.offset         = XtOffsetOf(php_phongo_serverdescription_t, std);
+}
 
-	zend_declare_class_constant_string(php_phongo_serverdescription_ce, ZEND_STRL("TYPE_UNKNOWN"), PHONGO_SERVER_TYPE_UNKNOWN);
-	zend_declare_class_constant_string(php_phongo_serverdescription_ce, ZEND_STRL("TYPE_STANDALONE"), PHONGO_SERVER_TYPE_STANDALONE);
-	zend_declare_class_constant_string(php_phongo_serverdescription_ce, ZEND_STRL("TYPE_MONGOS"), PHONGO_SERVER_TYPE_MONGOS);
-	zend_declare_class_constant_string(php_phongo_serverdescription_ce, ZEND_STRL("TYPE_POSSIBLE_PRIMARY"), PHONGO_SERVER_TYPE_POSSIBLE_PRIMARY);
-	zend_declare_class_constant_string(php_phongo_serverdescription_ce, ZEND_STRL("TYPE_RS_PRIMARY"), PHONGO_SERVER_TYPE_RS_PRIMARY);
-	zend_declare_class_constant_string(php_phongo_serverdescription_ce, ZEND_STRL("TYPE_RS_SECONDARY"), PHONGO_SERVER_TYPE_RS_SECONDARY);
-	zend_declare_class_constant_string(php_phongo_serverdescription_ce, ZEND_STRL("TYPE_RS_ARBITER"), PHONGO_SERVER_TYPE_RS_ARBITER);
-	zend_declare_class_constant_string(php_phongo_serverdescription_ce, ZEND_STRL("TYPE_RS_OTHER"), PHONGO_SERVER_TYPE_RS_OTHER);
-	zend_declare_class_constant_string(php_phongo_serverdescription_ce, ZEND_STRL("TYPE_RS_GHOST"), PHONGO_SERVER_TYPE_RS_GHOST);
-	zend_declare_class_constant_string(php_phongo_serverdescription_ce, ZEND_STRL("TYPE_LOAD_BALANCER"), PHONGO_SERVER_TYPE_LOAD_BALANCER);
-} /* }}} */
-
-void phongo_serverdescription_init_ex(zval* return_value, mongoc_server_description_t* server_description, bool copy) /* {{{ */
+void phongo_serverdescription_init_ex(zval* return_value, mongoc_server_description_t* server_description, bool copy)
 {
 	php_phongo_serverdescription_t* intern;
 
@@ -339,7 +290,6 @@ void phongo_serverdescription_init_ex(zval* return_value, mongoc_server_descript
 	intern                     = Z_SERVERDESCRIPTION_OBJ_P(return_value);
 	intern->server_description = copy ? mongoc_server_description_new_copy(server_description) : server_description;
 }
-/* }}} */
 
 php_phongo_server_description_type_t php_phongo_server_description_type(mongoc_server_description_t* sd)
 {
