@@ -22,6 +22,18 @@
 #ifndef MONGOC_CONFIG_H
 #define MONGOC_CONFIG_H
 
+/* clang-format off */
+
+/*
+ * NOTICE:
+ * If you're about to update this file and add a config flag, make sure to
+ * update:
+ * o The bitfield in mongoc-handshake-private.h
+ * o _mongoc_handshake_get_config_hex_string() in mongoc-handshake.c
+ * o examples/parse_handshake_cfg.py
+ * o test_handshake_config_string in test-mongoc-handshake.c
+ */
+
 /* MONGOC_USER_SET_CFLAGS is set from config based on what compiler flags were
  * used to compile mongoc */
 #define MONGOC_USER_SET_CFLAGS ""
@@ -353,13 +365,18 @@
 /*
  * Set if tracing is enabled. Logs things like network communication and
  * entry/exit of certain functions.
- *
  */
 #define MONGOC_TRACE 1
 
-#if MONGOC_TRACE != 1
-#  undef MONGOC_TRACE
-#endif
+enum {
+   /**
+    * @brief Compile-time constant determining whether the mongoc library was
+    * compiled with tracing enabled.
+    *
+    * Can be controlled with the 'ENABLE_TRACING" configure-time boolean option
+    */
+   MONGOC_TRACE_ENABLED = MONGOC_TRACE
+};
 
 /*
  * Set if we have ICU support.
@@ -386,7 +403,7 @@
  * Set if struct sockaddr_storage has __ss_family (instead of ss_family)
  */
 
-#define MONGOC_HAVE_SS_FAMILY 0
+#define MONGOC_HAVE_SS_FAMILY 1
 
 #if MONGOC_HAVE_SS_FAMILY != 1
 #  undef MONGOC_HAVE_SS_FAMILY
@@ -401,14 +418,6 @@
 #  undef MONGOC_ENABLE_MONGODB_AWS_AUTH
 #endif
 
-/*
- * NOTICE:
- * If you're about to update this file and add a config flag, make sure to
- * update:
- * o The bitfield in mongoc-handshake-private.h
- * o _mongoc_handshake_get_config_hex_string() in mongoc-handshake.c
- * o examples/parse_handshake_cfg.py
- * o test_handshake_config_string in test-mongoc-handshake.c
- */
+/* clang-format on */
 
 #endif /* MONGOC_CONFIG_H */
